@@ -14,15 +14,13 @@ import java.util.regex.Pattern;
  * @author Hiroyuki Shiota
  */
 public class StringUtil {
-	private static StringUtil singleton = new StringUtil();
-	private static HashMap repeatedCharsCash = new HashMap();
 
 	/**
 	 * RXgN^
 	 */
 	private StringUtil() {
 	}
-	
+
 	/**
 	 * ŏ݂̂̕uς
 	 * @param target - uΏە
@@ -69,7 +67,7 @@ public class StringUtil {
 		}
 		return new String(sb);
 	}
-	
+
 	/**
 	 * 𕪊
 	 * @param args
@@ -92,12 +90,10 @@ public class StringUtil {
 				return retStrs;
 			}
 			list.add(args.substring(pos, idx));
-			//System.out.println(strTemp+","+idx+","+pos+"+"+list);
 			pos = idx+delim.length();
-			//return null;
 		}
 	}
-	
+
 	/**
 	 * ̂݃g
 	 * @param str
@@ -115,7 +111,7 @@ public class StringUtil {
 		}
 		return str.substring(index, len);
 	}
-	
+
 	/**
 	 * Ê݃g
 	 * @param str
@@ -133,7 +129,7 @@ public class StringUtil {
 		}
 		return str.substring(0, index);
 	}
-	
+
 	/**
 	 * ɋl߂̂
 	 * @param str
@@ -154,12 +150,12 @@ public class StringUtil {
 	public static String padLeft(String str, int len, char pad) {
 		int padding_len = len - str.length();
 		if (padding_len > 0) {
-			return getRepeatedChars(pad, padding_len) + str;
+			return repeat(pad, padding_len) + str;
 		} else {
 			return str;
 		}
 	}
-	
+
 	/**
 	 * Eɋl߂̂
 	 * @param str
@@ -180,12 +176,12 @@ public class StringUtil {
 	public static String padRight(String str, int len, char pad) {
 		int padding_len = len - str.length();
 		if (padding_len > 0) {
-			return str + getRepeatedChars(pad, padding_len);
+			return str + repeat(pad, padding_len);
 		} else {
 			return str;
 		}
 	}
-	
+
 	/**
 	 * uPbgň͂
 	 * @param str
@@ -195,7 +191,7 @@ public class StringUtil {
 	public static String wrapBracket(String str, String both) {
 		return both + str + both;
 	}
-	
+
 	/**
 	 * uPbgň͂
 	 * @param str
@@ -206,7 +202,7 @@ public class StringUtil {
 	public static String wrapBracket(String str, String left, String right) {
 		return left + str + right;
 	}
-	
+
 	/**
 	 * uPbgO
 	 * @param str
@@ -227,7 +223,7 @@ public class StringUtil {
 		}
 		return result;
 	}
-	
+
 	/**
 	 * uPbgO
 	 * @param str
@@ -249,7 +245,7 @@ public class StringUtil {
 		}
 		return result;
 	}
-	
+
 	/**
 	 * ^uXy[Xɒu
 	 * @param str
@@ -257,9 +253,9 @@ public class StringUtil {
 	 * @return
 	 */
 	public static String tabToSpace(String str, int spaceLen) {
-		return str.replaceAll("\t", getRepeatedSpaces(spaceLen));
+		return str.replaceAll("\t", repeat(' ', spaceLen));
 	}
-	
+
 	/**
 	 * Xy[X^uɒu
 	 * @param str
@@ -267,63 +263,63 @@ public class StringUtil {
 	 * @return
 	 */
 	public static String spaceToTab(String str, int spaceLen) {
-		return str.replaceAll(getRepeatedSpaces(spaceLen), "\t");
+		return str.replaceAll(repeat(' ', spaceLen), "\t");
 	}
-	
+
 	/**
 	 * Cӂ̒̃Xy[X擾
 	 * @param len
 	 * @return
+	 * @deprecated {@link StringUtil#repeat(char c, int len)}
 	 */
 	public static String getRepeatedSpaces(int len) {
-		return getRepeatedChars(' ', len);
+		return repeat(' ', len);
 	}
-	
+
 	/**
 	 * Cӂ̒̕擾
 	 * @param s
 	 * @param len
 	 * @return
+	 * @deprecated {@link StringUtil#repeat(char c, int len)}
 	 */
 	public static String getRepeatedChars(String s, int len) {
 		if (s.length() != 1) throw new IllegalArgumentException(s);
-		return getRepeatedChars(s.charAt(0), len);
+		return repeat(s.charAt(0), len);
 	}
-	
+
 	/**
 	 * gCӂ̒̕擾
 	 * @param c
 	 * @param len
 	 * @return
 	 */
-	public static String getRepeatedChars(char c, int len) {
-		Character cobj = new Character(c);
-		StringBuffer sb = null;
-		if (repeatedCharsCash.containsKey(cobj)) {
-			sb = (StringBuffer)repeatedCharsCash.get(cobj);
-		} else {
-			sb = new StringBuffer();
-			repeatedCharsCash.put(cobj, sb);
-		}
-		int buffer_len = sb.length();
-		if (buffer_len >= len) {
-			return sb.substring(0, len);
-		} else {
-			for (int i = buffer_len; i < len; i++) {
-				sb.append(c);
-			}
-			return sb.substring(0, len);
+	public static String repeat(char c, int len) {
+		StringBuffer buff = new StringBuffer(len);
+		for (int i = 0; i < len; i++) {
+			buff.append(c);
 		}
+		return new String(buff);
 	}
-	
+
+	/**
+	 * gCӂ̒̕擾
+	 * @param c
+	 * @param len
+	 * @return
+	 * @deprecated {@link StringUtil#repeat(char c, int len)}
+	 */
+	public static String getRepeatedChars(char c, int len) {
+		return repeat(c, len);
+	}
+
 	/**
 	 * LbVNA
+	 * @deprecated
 	 */
 	public static void clearRepeatedCharsCash() {
-		repeatedCharsCash.clear();
-		repeatedCharsCash = new HashMap();
 	}
-	
+
 	/**
 	 * n̍قeequals\bh
 	 * @param str1
@@ -339,7 +335,7 @@ public class StringUtil {
 		//System.out.println("str1=[" + str1 + "] str2=[" + str2 + "] noise=" + noise);
 		return (noise <= err);
 	}
-	
+
 	/**
 	 * فimCYj̐𐔂
 	 * @param str1
@@ -381,7 +377,7 @@ public class StringUtil {
 		}
 		return noise+minErr;
 	}
-	
+
 	private static int equalHeads(String str1, String str2) {
 		int minlen = (str1.length() < str2.length()) ? str1.length() : str2.length();
 		for (int i = 0; i < minlen; i++) {
@@ -389,7 +385,7 @@ public class StringUtil {
 		}
 		return minlen;
 	}
-	
+
 	/**
 	 * z𕶎ɕϊ
 	 * @param args
@@ -408,7 +404,7 @@ public class StringUtil {
 		}
 		return new String(buf);
 	}
-	
+
 	/**
 	 * zƔz̔r
 	 * @param arg1
@@ -430,7 +426,7 @@ public class StringUtil {
 		}
 		return true;
 	}
-	
+
 	/**
 	 * URLGR[h
 	 * @param str
@@ -440,7 +436,7 @@ public class StringUtil {
 	public static String urlEncode(String str) {
 		return encodeURL(str, "utf-8");
 	}
-	
+
 	/**
 	 * URLGR[h
 	 * @param str
@@ -451,7 +447,7 @@ public class StringUtil {
 	public static String urlEncode(String str, String encoding) {
 		return encodeURL(str, encoding);
 	}
-	
+
 	/**
 	 * URLfR[h
 	 * @param str
@@ -461,7 +457,7 @@ public class StringUtil {
 	public static String urlDecode(String str) {
 		return decodeURL(str, "utf-8");
 	}
-	
+
 	/**
 	 * URLfR[h
 	 * @param str
@@ -472,7 +468,7 @@ public class StringUtil {
 	public static String urlDecode(String str, String encoding) {
 		return decodeURL(str, encoding);
 	}
-	
+
 	/**
 	 * URLGR[h
 	 * @param str
@@ -482,7 +478,7 @@ public class StringUtil {
 	public static String encodeURL(String str) {
 		return encodeURL(str, "utf-8");
 	}
-	
+
 	/**
 	 * URLGR[h
 	 * @param str
@@ -497,7 +493,7 @@ public class StringUtil {
 			return null;
 		}
 	}
-	
+
 	/**
 	 * URLfR[h
 	 * @param str
@@ -507,7 +503,7 @@ public class StringUtil {
 	public static String decodeURL(String str) {
 		return decodeURL(str, "utf-8");
 	}
-	
+
 	/**
 	 * URLfR[h
 	 * @param str
@@ -523,7 +519,7 @@ public class StringUtil {
 			return null;
 		}
 	}
-	
+
 	/**
 	 * HTMLGXP[v
 	 * @param str
@@ -562,7 +558,7 @@ public class StringUtil {
 		Matcher match = pattern.matcher(str);
 		return match.find();
 	}
-	
+
 	/**
 	 * }b`
 	 * @param str
